Crate expand_any_lifetime

Crate expand_any_lifetime 

续命

Note

DO NOT USE THIS IN ANY CODE YOU DON’T WANT MESS UP

Why?

You want to expand some lifetime without either call *::leak()

How?

An issue had opened for decades

In essence, it’s because static checking of multi-level lifetimes itself is inherently complex

Credits

Also check examples in cve-rs,

to find ‘what kind of memory vulnerabilities we could face with unconditional lifetime expand’?

Functions

续命